/*
*  RAL -- Rubrica Addressbook Library
*  file: groups.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _R_GROUP_SET_H
#define _R_GROUP_SET_H

#include <glib.h>
#include <glib-object.h>

#include "group.h"

#define R_GROUP_SET_TYPE           (r_group_set_get_type())

#define R_GROUP_SET(obj)           (G_TYPE_CHECK_INSTANCE_CAST((obj),     \
                                    R_GROUP_SET_TYPE, RGroupSet))

#define R_GROUP_SET_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST((klass),      \
                                    R_GROUP_SET_TYPE, RGroupSetClass))

#define IS_R_GROUP_SET(obj)        (G_TYPE_CHECK_INSTANCE_TYPE((obj),     \
                                    R_GROUP_SET_TYPE))

#define IS_R_GROUP_SET_CLASS(kls)  (G_TYPE_CHECK_CLASS_TYPE((kls),        \
                                    R_GROUP_SET_TYPE))

#define R_GROUP_SET_GET_CLASS(kls) (G_TYPE_INSTANCE_GET_CLASS((kls),      \
			            R_GROUP_SET_TYPE, RGroupSetClass))



typedef struct _RGroupSet        RGroupSet;
typedef struct _RGroupSetClass   RGroupSetClass;
typedef struct _RGroupSetPrivate RGroupSetPrivate;


struct _RGroupSet {
  GObject parent;
  
  RGroupSetPrivate* private;  
};


struct _RGroupSetClass {
  GObjectClass parent;

  void (*group_added)   (RGroupSet*, gpointer group);
  void (*group_removed) (RGroupSet*, gpointer group);
};



GType      r_group_set_get_type (void);



RGroupSet* r_group_set_new          (void);
void       r_group_set_free         (RGroupSet* set);


gpointer   r_group_set_find         (RGroupSet* set, gchar* group_name);
gboolean   r_group_set_owns_group   (RGroupSet* set, gchar* group_name);
gboolean   r_group_set_add_group    (RGroupSet* set, RGroup* group);
gboolean   r_group_set_rename_group (RGroupSet* set, gchar* oldname,
				     gchar* newname);

void       r_group_set_disable_all   (RGroupSet* set);
void       r_group_set_enable_group  (RGroupSet* set, RGroup* group);
void       r_group_set_disable_group (RGroupSet* set, RGroup* group);

gboolean   r_group_set_delete_group         (RGroupSet* set, RGroup* group);
gboolean   r_group_set_delete_group_by_name (RGroupSet* set, gchar* name);

GList*     r_group_set_find_groups_owned_by (RGroupSet* set,
					     const gchar* owner);

void       r_group_set_reset          (RGroupSet* set);
RGroup*    r_group_set_get_group      (RGroupSet* set);
RGroup*    r_group_set_get_next_group (RGroupSet* set);
RGroup*    r_group_set_get_prev_group (RGroupSet* set);

RGroupSet* r_group_set_merge_sets     (RGroupSet* set, RGroupSet* second);
#endif
